﻿using System;
using System.Drawing;
using System.Drawing.Imaging;
using System.Threading;
using System.Web.Mvc;
using AwesomeSlider.Extensions;
using AwesomeSlider.Models;
using AwesomeSlider.MVC;
using AwesomeSlider.Services;
using Orchard.ContentManagement;

namespace AwesomeSlider.Controllers
{
    public class SliderItemHandlingController: Controller
    {
        private IMediaExtendedService _mediaExtendedService;
        private readonly ISliderItemService _sliderItemService;
        private readonly ISliderService _sliderService;

        public SliderItemHandlingController(IMediaExtendedService mediaExtendedService, ISliderItemService sliderItemService, ISliderService sliderService)
        {
            _mediaExtendedService = mediaExtendedService;
            _sliderItemService = sliderItemService;
            _sliderService = sliderService;
        }

        [OutputCache(Duration = 60, VaryByParam="*")]
        public ActionResult Thumb(int photoId, int width, int height)
        {
            var imgPart = _sliderItemService.Get(photoId, VersionOptions.Latest).As<SliderItemPart>();
            if (imgPart == null)
                return HttpNotFound();

            string url = _mediaExtendedService.GetPublicUrl(imgPart.FullPath);
            string localPath = Server.MapPath(url);

            try
            {
                using (Image img = Image.FromFile(localPath))
                {
                    ImageFormat format = img.RawFormat;

                    Size thumbSize = img.GetNewSize(new Size(width, height));
                    var newImage = img.ResizeImage(thumbSize);
                    return new ImageResult(newImage, format);
                }
            }
            catch (Exception)
            {
                return HttpNotFound();
            }
        }
    }
}